@@ -2,10 +2,8 @@ from datetime import datetime, date, time
 from sqlalchemy import create_engine
 from sqlalchemy.orm import scoped_session, sessionmaker, aliased
 from sqlalchemy.dialects import mysql
-from sqlalchemy import exists
-from sqlalchemy import exists, and_
+from sqlalchemy import exists, desc, text, and_
 from sqlalchemy.inspection import inspect
-from sqlalchemy import desc
 
 from scrapeanything.utils.types import Types
 from scrapeanything.utils.utils import Utils
@@ -260,6 +258,13 @@ class Repository:
     def query(self, entity_type):
         return self.session.query(entity_type)
 
+    def sql(self, query: str, parameters: dict) -> any:
+        '''
+        Executes sql query. Make sure you use :parameter for parameters
+        '''
+        q = text(query)
+        return self.engine.execute(q, parameters)
+
     def assign(self, entity, prop, value):
         loaded_value = self.load(entity=value)
         value = self.update(entity_from_database=loaded_value, entity=value)
